aneyman <- function(x,k=0,Lag.max=50)
{ 
   #x is a time series to be tested whether it is a white noise by using
   #the adaptive Neyman test
   #k = p+q, if x is the residual from the ARMA(p,q) fit
   #Output:  The normalized statistic ANT and its order
   #         Chi^2 test at order Lag.max
   if(Lag.max - k < 5) {print("too small value of Lag.max"); break;}

   rho <- acf(x,Lag.max, plot=F)$acf    #compute the autocorrelation function
   rho <- rho[-1]
   n <- length(x)
   rho <- n*(n+2)*rho^2/(n-(1:length(rho)))
   rho <- cumsum(rho)
   Chisq <- rho[Lag.max]                #chisq statistic based on all Lag.max 
    					#coefficient
   Pvalue <- 1 - pchisq(Chisq, Lag.max-k)
   m <- 1:Lag.max
   rho <- (rho - m - k)/sqrt(2*(m-k))
   mhat <- k + order(rho[(k+1):Lag.max])[Lag.max-k] 
   ant <- rho[mhat]
   ANT <-  sqrt(2* log(log(Lag.max-k))) *ant - (2*log(log(Lag.max-k))+ 
	     0.5*log(log(log(Lag.max-k))) - 0.5*log(4*pi) )
   list(mhat=mhat, ANT=ANT, Chisq = Chisq, P.value.chisq =Pvalue) 
}
